@@ -38,6 +38,6 @@
  */
 #import <Foundation/Foundation.h>
 #import <AppKit/AppKit.h>
-#import <AppKit/GSHbox.h>
-#import <AppKit/GSVbox.h>
+#import <GNUstepGUI/GSHbox.h>
+#import <GNUstepGUI/GSVbox.h>
 
